@@ -1,11 +1,11 @@
 use strict;
 use warnings;
-package Dist::Zilla::PluginBundle::Author::ETHER; # git description: v0.114-9-g197f8a5
+package Dist::Zilla::PluginBundle::Author::ETHER; # git description: v0.115-8-g7c1193c
 # vim: set ts=8 sts=4 sw=4 tw=115 et :
 # ABSTRACT: A plugin bundle for distributions built by ETHER
 # KEYWORDS: author bundle distribution tool
 
-our $VERSION = '0.115';
+our $VERSION = '0.116';
 
 use Moose;
 with
@@ -241,7 +241,7 @@ sub configure
         [ 'Test::ReportPrereqs' => { ':version' => '0.022', verify_prereqs => 1, version_extractor => 'Module::Metadata',
             exists $removed{PodCoverageTests} ? () : ( include => [ 'Pod::Coverage' ] ),
           } ],
-        'Test::Portability',
+        [ 'Test::Portability'   => { ':version' => '2.000007' } ],
         [ 'Test::CleanNamespaces' => { ':version' => '0.006' } ],
 
 
@@ -265,7 +265,6 @@ sub configure
             : $self->server eq 'catagits' ? ( 'repository.catagits' => 1 )
             : ()
         } ],
-        [ 'AuthorityFromModule' => { ':version' => '0.002' } ],
         [ 'Authority'           => { ':version' => '1.009', authority => 'cpan:ETHER', do_munging => 0 } ],
         [ 'MetaNoIndex'         => { directory => [ qw(t xt), grep { -d } qw(inc local perl5 fatlib examples share corpus demo) ] } ],
         [ 'MetaProvides::Package' => { ':version' => '1.15000002', finder => ':InstallModules', meta_noindex => 1, inherit_version => 0, inherit_missing => 0 } ],
@@ -457,7 +456,7 @@ Dist::Zilla::PluginBundle::Author::ETHER - A plugin bundle for distributions bui
 
 =head1 VERSION
 
-version 0.115
+version 0.116
 
 =head1 SYNOPSIS
 
@@ -589,6 +588,7 @@ following F<dist.ini> (following the preamble), minus some optimizations:
     version_extractor = Module::Metadata
     include = Pod::Coverage
     [Test::Portability]
+    :version = 2.000007
     [Test::CleanNamespaces]
     :version = 0.006
 
@@ -615,8 +615,6 @@ following F<dist.ini> (following the preamble), minus some optimizations:
     bugtracker.rt = 1
     ; (plus repository.* = 1 if server = 'gitmo' or 'p5sagit')
 
-    [AuthorityFromModule]
-    :version = 0.002
     [Authority]
     :version = 1.009
     authority = cpan:ETHER
